@@ -78,6 +78,9 @@ CANBUS_ERROR_CODES = {
     'canbus_up_failed',
 }
 
+class ElfHashMismatch(Exception):
+    pass
+
 
 def quote(gateway):
     return urllib.parse.quote(str(gateway), safe='')
@@ -99,9 +102,10 @@ class LagerSession(BaseUrlSession):
         except RuntimeError:
             pass
         if r.status_code == 404:
-            if '/api/v1/gateway/1/download-file' in r.request.path_url:
+            parts = r.request.path_url.split('/')
+            if len(parts) > 2 and 'download-file?filename=' in parts[-1]:
                 r.raise_for_status()
-            name = ctx.params['gateway'] or ctx.obj.default_gateway
+            name = ctx.params.get('gateway') or ctx.params.get('dut') or ctx.obj.default_gateway
             click.secho('You don\'t have a gateway with id `{}`'.format(name), fg='red', err=True)
             click.secho(
                 'Please double check your login credentials and gateway id',
@@ -113,6 +117,8 @@ class LagerSession(BaseUrlSession):
             error = r.json()['error']
             if error['code'] == 'gateway_timeout_error':
                 raise GatewayTimeoutError(error['description'])
+            if error['code'] == 'elf_hash_mismatch':
+                raise ElfHashMismatch()
 
             if error['code'] in OPENOCD_ERROR_CODES:
                 print_openocd_error(error['description'])
@@ -211,6 +217,48 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/start-debugger'.format(quote(gateway))
         return self.post(url, files=files)
 
+    def debug_connect(self, gateway, mcu, force, ignore_if_connected):
+        """
+            connect debugger by mcu
+        """
+        url = 'gateway/{}/debug-connect'.format(quote(gateway))
+        return self.post(url, json={'mcu': mcu, 'force': force, 'ignore_if_connected': ignore_if_connected})
+
+    def debug_disconnect(self, gateway, mcu):
+        """
+            disconnect debugger by mcu
+        """
+        url = 'gateway/{}/debug-disconnect'.format(quote(gateway))
+        return self.post(url, json={'mcu': mcu})
+
+    def debug_erase(self, gateway, mcu):
+        """
+            erase debugger by mcu
+        """
+        url = 'gateway/{}/debug-erase'.format(quote(gateway))
+        return self.post(url, json={'mcu': mcu})
+
+    def debug_reset(self, gateway, mcu, halt):
+        """
+            erase debugger by mcu
+        """
+        url = 'gateway/{}/debug-reset'.format(quote(gateway))
+        return self.post(url, json={'mcu': mcu, 'halt': halt})
+
+    def net_action(self, gateway, data):
+        """
+            Net action
+        """
+        url = 'gateway/{}/net/action'.format(quote(gateway))
+        return self.post(url, json=data)
+
+    def debug_flash(self, gateway, files):
+        """
+            flash debugger by mcu
+        """
+        url = 'gateway/{}/debug-flash'.format(quote(gateway))
+        return self.post(url, files=files)
+
     def stop_debugger(self, gateway):
         """
             Stop the debugger on the gateway
@@ -274,12 +322,12 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/serial-ports'.format(quote(gateway))
         return self.get(url)
 
-    def gateway_status(self, gateway):
+    def gateway_status(self, gateway, mcu):
         """
             Get debugger status on gateway
         """
         url = 'gateway/{}/status'.format(quote(gateway))
-        return self.get(url)
+        return self.get(url, params={'mcu': mcu})
 
     def list_gateways(self):
         """
@@ -288,12 +336,12 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/list'
         return self.get(url)
 
-    def reset_dut(self, gateway, halt):
+    def reset_dut(self, gateway, halt, mcu):
         """
             Reset the DUT attached to a gateway and optionally halt it
         """
         url = 'gateway/{}/reset-duck'.format(quote(gateway))
-        return self.post(url, json={'halt': halt})
+        return self.post(url, json={'halt': halt, 'mcu': mcu})
 
     def run_dut(self, gateway):
         """
@@ -316,17 +364,32 @@ class LagerSession(BaseUrlSession):
         }
         return self.post(url, json=json_data)
 
-    def remote_debug(self, gateway, archive, args):
+    def remote_debug(self, gateway, use_cache, archive, args):
         """
             Start a remote debugging session
         """
         url = 'gateway/{}/remote-debug'.format(quote(gateway))
-
         files = [
-            ('archive', archive),
             ('args', json.dumps(args)),
         ]
-        return self.post(url, files=files)
+        if not use_cache:
+            files.append(
+                ('archive', archive),
+            )
+        else:
+            files.append(
+                ('archive', ''),
+            )
+
+        try:
+            return self.post(url, files=files)
+        except ElfHashMismatch:
+            files = [
+                ('args', json.dumps(args)),
+                ('archive', archive),
+            ]
+            print('retry')
+            return self.post(url, files=files)
 
     def rename_gateway(self, gateway, new_name):
         """
@@ -419,12 +482,12 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/wifi/connect'.format(quote(gateway))
         return self.post(url, json={'ssid': ssid, 'password': password, 'interface': interface})
 
-    def delete_wifi_connection(self, gateway, ssid, interface):
+    def delete_wifi_connection(self, gateway, ssid):
         """
             Delete the wifi connection for the specified gateway
         """
         url = 'gateway/{}/wifi/delete-connection'.format(quote(gateway))
-        return self.post(url, json={'ssid': ssid, 'interface': interface})
+        return self.post(url, json={'ssid': ssid})
 
     def can_up(self, gateway, bitrate, interfaces):
         """
@@ -512,6 +575,27 @@ class LagerSession(BaseUrlSession):
             return None
         return region
 
+    def start_dev_factory(self, gateway):
+        """
+            start a dev factory
+        """
+        url = 'gateway/{}/start-dev-factory'.format(quote(gateway))
+        return self.post(url)
+
+    def all_muxes(self, gateway):
+        """
+            get the muxes for the DUT
+        """
+        url = 'gateway/{}/all-muxes'.format(quote(gateway))
+        return self.get(url)
+
+    def usb_command(self, gateway, data):
+        """
+            run a USB command
+        """
+        url = 'gateway/{}/usb'.format(quote(gateway))
+        return self.post(url, json=data)
+
 class LagerContext:  # pylint: disable=too-few-public-methods
     """
         Lager Context manager
@@ -552,6 +636,8 @@ class LagerContext:  # pylint: disable=too-few-public-methods
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/3333'
         elif socktype == 'openocd-tunnel':
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/4444'
+        elif socktype == 'rtt':
+            path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/9090'
         elif socktype == 'webcam-tunnel':
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/8081'
         elif socktype == 'pdb':
@@ -619,12 +705,12 @@ def get_ssl_context():
     ctx.load_verify_locations(cafile=cafile_path)
     return ctx
 
-def ensure_debugger_running(gateway, ctx):
+def ensure_debugger_running(gateway, ctx, mcu=None):
     """
         Ensure debugger is running on a given gateway
     """
     session = ctx.obj.session
-    gateway_status = session.gateway_status(gateway).json()
+    gateway_status = session.gateway_status(gateway, mcu).json()
     if not gateway_status['running']:
         click.secho('Gateway debugger is not running. Please use `lager connect` to run it', fg='red', err=True)
         ctx.exit(1)
@@ -659,6 +745,8 @@ def get_ci_environment():
     """
         Determine whether we are running in CI or not
     """
+    if os.getenv('LAGER_CI_OVERRIDE'):
+        return CIEnvironment.HOST
 
     if os.getenv('CI') == 'true':
         if os.getenv('DRONE') == 'true':
