@@ -99,11 +99,26 @@ def terminal(ctx, mount, user, group, name, detach, port):
         mount_dir,
     ]
 
+    if 'user' in section:
+        user = section['user']
+    if 'group' in section:
+        group = section['group']
+    macaddr = None
+    if 'macaddr' in section:
+        macaddr = section['macaddr']
+
+    hostname = None
+    if 'hostname' in section:
+        hostname = section['hostname']
 
     if user:
         args.extend(['--user', user])
     if group:
         args.extend(['--group', group])
+    if macaddr:
+        args.extend(['--mac-address', macaddr])
+    if hostname:
+        args.extend(['--hostname', hostname])
 
     if mount:
         args.extend(['--mount', f'source={mount},target={mount_dir}'])
