@@ -10,10 +10,11 @@ from ..util import stream_output
 
 @click.command()
 @click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--gateway', '--dut', required=False, help='ID of gateway to which DUT is connected')
 @click.argument('start_addr', type=MemoryAddressType())
 @click.argument('length', type=MemoryAddressType())
-def erase(ctx, gateway, start_addr, length):
+@click.option('--mcu', required=False, default=None, help='MCU to target', type=click.INT)
+def erase(ctx, gateway, start_addr, length, mcu):
     """
         Erase DUT
     """
@@ -21,6 +22,6 @@ def erase(ctx, gateway, start_addr, length):
         gateway = get_default_gateway(ctx)
 
     session = ctx.obj.session
-    addresses = dict(start_addr=start_addr, length=length)
+    addresses = dict(start_addr=start_addr, length=length, mcu=mcu)
     resp = session.erase_dut(gateway, addresses=addresses)
     stream_output(resp)
