@@ -107,18 +107,12 @@ class BinfileType(click.ParamType):
     def __repr__(self):
         return 'BINFILE'
 
-@_gateway.command()
-@click.pass_context
-@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
-def status(ctx, gateway):
-    """
-        Get gateway debugger status
-    """
+def _status(ctx, gateway, mcu):
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
     session = ctx.obj.session
-    response = session.gateway_status(gateway).json()
+    response = session.gateway_status(gateway, mcu).json()
     running = response['running']
     cmdline = response['cmdline']
     logfile = response['logfile']
@@ -138,12 +132,25 @@ def status(ctx, gateway):
         click.echo('---- Logs ----')
         click.echo(logfile)
 
+@_gateway.command()
+@click.pass_context
+@click.option('--gateway', required=False, help='ID of gateway to which DUT is connected')
+@click.option('--mcu', required=False, default=None, help='MCU to query', type=click.INT)
+def status(ctx, gateway, mcu):
+    """
+        Get gateway debugger status
+    """
+    _status(ctx, gateway, mcu)
+
 
 @_gateway.command()
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway to rename')
 @click.option('--to', required=True, help='New name for gateway')
 def rename(ctx, gateway, to):
+    """
+        Rename a gateway
+    """
     if gateway is None:
         gateway = get_default_gateway(ctx)
 
