@@ -114,7 +114,7 @@ def _get_signal_number(name):
 @click.option('--download', type=click.Path(exists=False, dir_okay=False), multiple=True, help='Download named files from gateway after script completes')
 @click.option('--allow-overwrite', is_flag=True, default=False, help='Allow overwriting existing files with --download')
 @click.option('--signal', 'signum', default='SIGTERM', type=_SIGNAL_CHOICES, help='Signal to use with --kill', show_default=True)
-@click.option('--timeout', type=click.INT, required=False, help='Max runtime in seconds for the python script')
+@click.option('--timeout', type=click.INT, default=0, required=False, help='Max runtime in seconds for the python script')
 @click.option('--detach', '-d', is_flag=True, required=False, default=False, help='Detach')
 @click.option('--port', '-p', multiple=True, help='Forward ports to the lager python process. Syntax: -p SRC_PORT[:DST_PORT][/PROTOCOL]. Example: -p 1234:4567/udp to forward UDP traffic on port 1234 to port 4567 in the lager python process. To forward traffic to the same port in the container, simply use -p PORT e.g. -p 1234 to forward all traffic on port 1234 to port 1234 in the lager python process.', type=PortForwardType())
 @click.argument('args', nargs=-1)
