@@ -30,6 +30,16 @@ def gateway(gateway_id):
     config.set('LAGER', 'gateway_id', gateway_id)
     write_config_file(config)
 
+@default.command()
+@click.argument('dut_id')
+def dut(dut_id):
+    """
+        Set default gateway
+    """
+    config = read_config_file()
+    config.set('LAGER', 'gateway_id', dut_id)
+    write_config_file(config)
+
 @default.command()
 @click.argument('device_path')
 def serial_device(device_path):
